@@ -23,7 +23,9 @@ def find_reason(
     """
     find reason for diffrence
     """
-    search_cols = [col for col in df.columns if df.dtypes[col].name in ["object"]]
+    search_cols = [
+        col for col in df.columns if df.dtypes[col].name in ["object", "bool"]
+    ]
     if compare_col not in search_cols:
         search_cols.append(compare_col)
     reason_df_map = {}
